ListDiff class

Represents the delta required to transform one list of nodes into another.

This is used for efficient UI updates (e.g., Flutter's AnimatedList). It provides indices to remove (in descending order) and indices to insert (in ascending order).

Constructors

ListDiff({required List<int> removeIndicesDesc, required List<int> insertIndicesAsc})
Creates a diff describing changes between two lists.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
insertIndicesAsc List<int>
Indices to insert into the new list, sorted ascending.
final
isNoop bool
Returns true if no changes are required.
no setter
removeIndicesDesc List<int>
Indices to remove from the previous list, sorted descending.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited